.. Copyright (C) 2016-2018 Reto Gantenbein <reto.gantenbein@linuxmonk.ch>
.. Copyright (C) 2016-2018 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

The ``debops.roundcube`` Ansible role manages `Roundcube`__, an IMAP Web client
written in PHP.

.. __: https://roundcube.net/
